@@ -1,4 +1,5 @@
 from pipewire_python.controller import Controller
+
 # import requests
 
 
@@ -13,15 +14,19 @@ from pipewire_python.controller import Controller
 # normal way
 def test_playback():
     audio_controller = Controller(verbose=True)
-    audio_controller.set_config(rate=384000,
-                                channels=2,
-                                _format='f64',
-                                volume=0.98,
-                                quality=4,
-                                # Debug
-                                verbose=True)
-    audio_controller.playback(audio_filename='docs/beers.wav',
-                              # Debug
-                              verbose=True)
+    audio_controller.set_config(
+        rate=384000,
+        channels=2,
+        _format="f64",
+        volume=0.98,
+        quality=4,
+        # Debug
+        verbose=True,
+    )
+    audio_controller.playback(
+        audio_filename="docs/beers.wav",
+        # Debug
+        verbose=True,
+    )
 
     assert type(audio_controller.get_config())
