@@ -1,4 +1,5 @@
 from pipewire_python.controller import Controller
+
 # import asyncio
 
 #########################
@@ -6,16 +7,20 @@ from pipewire_python.controller import Controller
 #########################
 # normal way
 audio_controller = Controller(verbose=True)
-audio_controller.set_config(rate=384000,
-                            channels=2,
-                            _format='f64',
-                            volume=0.98,
-                            quality=4,
-                            # Debug
-                            verbose=True)
-audio_controller.playback(audio_filename='docs/beers.wav',
-                          # Debug
-                          verbose=True)
+audio_controller.set_config(
+    rate=384000,
+    channels=2,
+    _format="f64",
+    volume=0.98,
+    quality=4,
+    # Debug
+    verbose=True,
+)
+audio_controller.playback(
+    audio_filename="docs/beers.wav",
+    # Debug
+    verbose=True,
+)
 
 # async way
 # player = Player()
@@ -28,10 +33,12 @@ audio_controller.playback(audio_filename='docs/beers.wav',
 
 # normal way
 audio_controller = Controller(verbose=True)
-audio_controller.record(audio_filename='docs/5sec_record.wav',
-                        timeout_seconds=5,
-                        # Debug
-                        verbose=True)
+audio_controller.record(
+    audio_filename="docs/5sec_record.wav",
+    timeout_seconds=5,
+    # Debug
+    verbose=True,
+)
 
 # async way
 # player = Player()
